@@ -1,11 +1,10 @@
 
 from cert_schema.jsonld_helpers import jsonld_document_loader, normalize_jsonld
 from cert_schema.schema_validator import validate_unsigned_v1_2, validate_v1_2, validate_v2, validate_v2_1,\
-    validate_v3_alpha, validate_v3_beta
+    validate_v3
 
-from cert_schema.jsonld_helpers import BLOCKCERTS_V3_BETA_CANONICAL_CONTEXT, BLOCKCERTS_V3_BETA_CONTEXT, \
-    BLOCKCERTS_V3_BETA_SCHEMA,BLOCKCERTS_V3_ALPHA_CANONICAL_CONTEXT, BLOCKCERTS_V3_ALPHA_CONTEXT, \
-    BLOCKCERTS_V3_ALPHA_SCHEMA, VERIFIABLE_CREDENTIAL_V1_CONTEXT, BLOCKCERTS_V2_ALPHA_CONTEXT, \
+from cert_schema.jsonld_helpers import BLOCKCERTS_V3_CANONICAL_CONTEXT, BLOCKCERTS_V3_CONTEXT, \
+    BLOCKCERTS_V3_SCHEMA, VERIFIABLE_CREDENTIAL_V1_CONTEXT, BLOCKCERTS_V2_ALPHA_CONTEXT, \
     BLOCKCERTS_V2_ALPHA_SCHEMA, BLOCKCERTS_V2_CONTEXT, BLOCKCERTS_V2_SCHEMA, BLOCKCERTS_V2_CANONICAL_CONTEXT, \
     BLOCKCERTS_VOCAB, JSONLD_OPTIONS, OPEN_BADGES_V2_CANONICAL_CONTEXT, OPEN_BADGES_V2_CONTEXT, SECURITY_CONTEXT_URL, \
     BLOCKCERTS_V2_1_CONTEXT, BLOCKCERTS_V2_1_SCHEMA, BLOCKCERTS_V2_1_CANONICAL_CONTEXT
